@@ -3,7 +3,7 @@ package JSON::Meth;
 use strict;
 use warnings;
 
-our $VERSION = '1.001005'; # VERSION
+our $VERSION = '1.001006'; # VERSION
 
 use JSON::MaybeXS;
 use 5.008001;
@@ -49,7 +49,7 @@ $json = $j = bless sub {
         unless ref $data;
 
     return $data = $json_obj->encode($data);
-}, 'JSON::Meth';
+}, __PACKAGE__;
 
 q{
     Q: How many programmers does it take to change a light bulb?
